#!/usr/local/bin/gnuplot -persist
set terminal pdf enhanced
set output 'fig/density-rank16.pdf'
#set terminal pngcairo size 600,400
#set output 'test.png'

set loadpath './'
load 'palette.pal'


set border 3 front lt black linewidth 1.000 dashtype solid
set boxwidth 0.8 absolute
set style fill solid 1.00 noborder
set grid nopolar
set grid noxtics nomxtics ytics nomytics noztics nomztics nortics nomrtics \
 nox2tics nomx2tics noy2tics nomy2tics nocbtics nomcbtics
set grid layerdefault  lt 0 linecolor 0 linewidth 0.500,  lt 0 linecolor 0 linewidth 0.500
set key bmargin center horizontal Left reverse noenhanced autotitle columnhead nobox
set style histogram rowstacked title textcolor lt -1 offset character 2, 0.2
unset parametric
set datafile missing '-'
set style data histograms
set xtics border in scale 0,0 nomirror  autojustify
#set xtics  norangelimit  font ",8"
set xtics   ()
set ytics border in scale 0,0 mirror norotate  autojustify
set ytics norangelimit autofreq  font ",8"
set ztics border in scale 0,0 nomirror norotate  autojustify
set cbtics border in scale 0,0 mirror norotate  autojustify
set rtics axis in scale 0,0 nomirror norotate  autojustify

# Set the labels for the X and Y axes and the title of the graph
set xlabel 'Porosity'
set ylabel 'Time/iter'
set title "Iteration time of IALO on balanced porous medium with 16 ranks"

# Set the range of the Y-axis and the format of the labels
set yrange [0:*]
set format y '%.2f s'

set colorbox vertical origin screen 0.9, 0.2 size screen 0.05, 0.6 front  noinvert bdefault

set datafile separator ','

# Plot the data using the remaining three columns as stacked bars
plot './data/density-IALO-400-comb.csv' \
  using 2:xticlabels(1) lc rgb color8 title 'Collide', \
  '' using 3 lc rgb color6 title 'Stream', \
  '' using 4 lc rgb color4 title 'Border exchange', \

set output

##############

set output "fig/density-comparison.pdf"

set style histogram clustered title textcolor lt -1 offset character 2, 0.2

set title "Comparison of LBM proxy applications on different porosity environments"


plot \
  './data/density-base-400-comb.csv' \
    using 5:xticlabels(1) lc rgb color7 title 'Base', \
  './data/density-IA-400-comb.csv' \
    using 5 lc rgb color5 title 'IA', \
  './data/density-IALO-400-comb.csv' \
    using 5 lc rgb green5 title 'IALO', \
  './data/porosity-1d-opt-comb.csv' \
    using 5 lc rgb green8 title 'IALO 1D'

set output
