#!/usr/local/bin/gnuplot
set terminal pdf enhanced
set output 'fig/scale-p50-400.pdf'
#set terminal pngcairo size 600,400
#set output 'test.png'

set loadpath './'
load 'palette.pal'


set border 3 front lt black linewidth 1.000 dashtype solid
set boxwidth 0.8 absolute
set style fill solid 1.00 noborder
set grid nopolar
set grid noxtics nomxtics ytics nomytics noztics nomztics nortics nomrtics \
 nox2tics nomx2tics noy2tics nomy2tics nocbtics nomcbtics
set grid layerdefault  lt 0 linecolor 0 linewidth 0.500,  lt 0 linecolor 0 linewidth 0.500
set key bmargin center horizontal Left reverse noenhanced autotitle columnhead nobox
set style histogram rowstacked title textcolor lt -1 offset character 2, 0.2
unset parametric
set datafile missing '-'
set style data histograms
set xtics border in scale 0,0 nomirror  autojustify
#set xtics  norangelimit  font ",8"
set xtics   ()
set ytics border in scale 0,0 mirror norotate  autojustify
set ytics norangelimit autofreq  font ",8"
set ztics border in scale 0,0 nomirror norotate  autojustify
set cbtics border in scale 0,0 mirror norotate  autojustify
set rtics axis in scale 0,0 nomirror norotate  autojustify

# Set the labels for the X and Y axes and the title of the graph
set xlabel 'Ranks'
set ylabel 'Time/iter'
set title "Iteration time for different ranks with 50% porosity model [IALO]"

# Set the range of the Y-axis and the format of the labels
set yrange [0:*]
set format y '%.2f s'

set colorbox vertical origin screen 0.9, 0.2 size screen 0.05, 0.6 front  noinvert bdefault

set datafile separator ','


plot './data/scale-IALO-p50-comb.csv' \
  using 3:xticlabels(1) lc rgb color8 title 'Collide', \
  '' using 4 lc rgb color6 title 'Stream', \
  '' using 5 lc rgb color4 title 'Border exchange'

set output

####################

set title "Scalability of IA with RCA 400"
set output 'fig/scale-RCA-400-IA.pdf'

plot './data/scale-IA-400-O3-comb.csv' \
  using 3:xticlabels(1) lc rgb color8 title 'Collide', \
  '' using 4 lc rgb color6 title 'Stream', \
  '' using 5 lc rgb color4 title 'Border exchange'

set output

####################

set title "Scalabiilty of base with RCA 400"
set output 'fig/scale-RCA-400-base.pdf'

plot './data/scale-base-RCA400-comb.csv' \
  using 3:xticlabels(1) lc rgb color8 title 'Collide', \
  '' using 4 lc rgb color6 title 'Stream', \
  '' using 5 lc rgb color4 title 'Border exchange'

set output

#####################
set title "Iteration time for different ranks with 50% porosity model [baseline]"
set output 'fig/scale-p50-400-baseline.pdf'

plot './data/scale-base-p50-comb.csv' \
  using 3:xticlabels(1) lc rgb color8 title 'Collide', \
  '' using 4 lc rgb color6 title 'Stream', \
  '' using 5 lc rgb color4 title 'Border exchange'

set output

#####################

set title "Iteration time for different ranks with 10% porosity model [baseline]"
set output 'fig/scale-p10-400-baseline.pdf'

plot './data/scale-base-p10-comb.csv' \
  using 3:xticlabels(1) lc rgb color8 title 'Collide', \
  '' using 4 lc rgb color6 title 'Stream', \
  '' using 5 lc rgb color4 title 'Border exchange'

set output

#####################

set title "Iteration time for different ranks with 10% porosity model [IALO]"
set output 'fig/scale-p10-400-IALO.pdf'

plot './data/scale-IALO-p10-comb.csv' \
  using 3:xticlabels(1) lc rgb color8 title 'Collide', \
  '' using 4 lc rgb color6 title 'Stream', \
  '' using 5 lc rgb color4 title 'Border exchange'

set output

###############

set style histogram clustered title textcolor lt -1 offset character 2, 0.2

set title "Scalabiilty of IA and IALO with 10% porosity model"
set output 'fig/scale-p10-400-comp.pdf'

plot './data/scale-base-p10-comb.csv' \
     using 6:xticlabels(1) lc rgb color8 title 'Baseline', \
  './data/scale-IA-p10-comb.csv' \
     using 6 lc rgb color7 title 'IA', \
  './data/scale-IALO-p10-comb.csv' \
     using 6 lc rgb color5 title 'IALO', \


set output

#####################

set style histogram clustered title textcolor lt -1 offset character 2, 0.2

set title "Comparison of scalabiilty of LBM with 50% porosity"
set output 'fig/scale-p50-400-comp.pdf'

plot './data/scale-base-p50-comb.csv' \
    using 6:xticlabels(1) lc rgb color8 title 'Baseline', \
 './data/scale-IA-p50-comb.csv' \
    using 6 lc rgb color7 title 'IA', \
 './data/scale-IALO-p50-comb.csv' \
    using 6 lc rgb color5 title 'IALO', \


set output

#################

set title "Comparison of the scalability of IA, IALO and IALO 1D on the RCA 400 model"
set output 'fig/scale-RCA-400-comp.pdf'

set yrange [0:*]

plot './data/scale-IA-400-O3-comb.csv' \
    using 6 lc rgb color7 title 'IA', \
  './data/scale-IALO-400-O3-comb.csv' \
    using 6:xticlabels(1) lc rgb color8 title 'IALO', \
  './data/scale-RCA-400-1dcart-comb.csv' \
  using 6 lc rgb green4 title 'IALO 1D'

set output
set yrange [0:*]


###################

set title "Scalabiilty of IA, IALO and IALO 1D on the RCA 1024 model"
set output 'fig/scale-RCA-1024.pdf'

set yrange [0:0.6]

plot './data/scale-IA-RCA1024-fram-comb.csv' \
    using 6 lc rgb color7 title 'IA', \
  './data/scale-IALO-RCA1024-fram-comb.csv' \
    using 6:xticlabels(1) lc rgb color8 title 'IALO', \
  './data/scale-IALO1D-RCA1024-fram-comb.csv' \
  using 6 lc rgb green4 title 'IALO 1D'

set yrange [0:*]
set output


#######################

# 32 ranks balance and work load

######################

set terminal pdf enhanced size 16cm,8cm font ",12"
set title "Rank balance of RCA 400 model with 32 ranks"
set output 'fig/scale-RCA-400-ranks.pdf'

set style histogram clustered title textcolor lt -1 offset character 2, 0.2
set xtics border in scale 0,0 nomirror  autojustify

set y2range [0:55000]
set format y '%.3f s'
set grid noxtics nomxtics ytics nomytics noztics nomztics nortics nomrtics \
 nox2tics nomx2tics noy2tics nomy2tics nocbtics nomcbtics
set y2tics nomirror

set xlabel 'Rank'
set y2label 'Nodes'

plot  './data/scale-IA-400-O3/lbm-perf-32.csv' \
    using 2:xticlabels(1) lc rgb red1f title "Fluid node count" with boxes  axes x2y2, \
    '' using 5 lc rgb color8 title 'Collide [IA]', \
    '' using 6 lc rgb color5 title 'Stream [IA]', \
    './data/scale-IALO-400-O3/lbm-perf-32.csv' \
    using 5 lc rgb green7 title 'Collide [IALO]', \
    '' using 6 lc rgb green5 title 'Stream [IALO]', \

set output


########################
# With 1D topology

set title "Rank balance of RCA 400 model with 32 ranks [IALO 1D]"
set output 'fig/scale-RCA-400-ranks-1dcart.pdf'

plot  './data/scale-RCA-400-1dcart/lbm-perf-32.csv' \
    using 2:xticlabels(1) lc rgb red1f title "Fluid node count" with boxes  axes x2y2, \
    '' using 5 lc rgb color8 title 'Collide [IALO 1D]', \
    '' using 6 lc rgb color5 title 'Stream [IALO 1D]', \


####################
# 10% topology

set y2range [0:400000]

set title "Rank balance of 10% porosity model with 32 ranks"
set output 'fig/scale-p10-400-ranks.pdf'

plot  './data/scale-IALO-p10/lbm-perf-32.csv' \
    using 2:xticlabels(1) lc rgb red1f title "Fluid node count" with boxes  axes x2y2, \
    '' using 5 lc rgb color8 title 'Collide [IALO]', \
    '' using 6 lc rgb color5 title 'Stream [IALO]', \



set output
